@@ -4,11 +4,22 @@ from django.forms import fields
 from django.template.loader import render_to_string
 from django_helpers.apps.forms.widgets import Widget
 from django_helpers.apps.autocomplete import register
+from django_helpers.apps.static_manager import jQueryURL
+
 
 class AutoCompleteWidget(Widget, fields.TextInput):
     formatted_value = None
     template = 'autocomplete/js/auto-complete.js'
 
+    js_files = (
+        jQueryURL,
+        'js/jquery-ui/jquery.ui.core.min.js',
+        'js/jquery-ui/jquery.ui.widget.min.js',
+        'js/jquery-ui/jquery.ui.position.min.js',
+        'js/jquery-ui/jquery.ui.menu.min.js',
+        'js/jquery-ui/jquery.ui.autocomplete.min.js',
+    )
+
     def __init__(self, attrs=None, delay=0, min_length=1, lookup=None):
         fields.TextInput.__init__(self, attrs)
         self.auto_complete = lookup()
@@ -92,7 +103,6 @@ class TokenInputWidget(Widget, fields.TextInput):
             self.instances = auto_complete.get_instances(value)
         return fields.TextInput.render(self, name, "", attrs)
 
-
     def render_js(self):
         source = reverse(self.auto_complete.name)
         instances = self.instances
