@@ -1,9 +1,11 @@
+# coding=utf-8
 from django import forms
 from django.utils.translation import ugettext_lazy as _
-from widgets import DateInput
+from django_helpers.apps.forms.widgets import DateInput
 from django_helpers.apps.autocomplete import fields
 from django_helpers.apps.autocomplete.widgets import AutoCompleteWidget, SimpleAutoCompleteWidget
 
+
 def set_property(field, args, name, target):
     if name in args:
         val = args[name]
@@ -78,7 +80,7 @@ def CharField(label=None, max_length=None, min_length=None,
         extra_options={
             "max_length": max_length,
             "min_length": min_length,
-            }
+        }
     )
 
 
@@ -93,7 +95,7 @@ def PasswordField(label=None, max_length=None, min_length=None,
         extra_options={
             "max_length": max_length,
             "min_length": min_length,
-            }
+        }
     )
 
 
@@ -131,14 +133,14 @@ def IntegerField(label=None, max_value=None, min_value=None,
     )
 
 
-def DateField(label=None, format=None, max_date=None,
+def DateField(label=None, date_format=None, max_date=None,
               min_date=None, change_year=None, change_month=None,
               required=None, class_names=None, class_name=None):
     return factory(
         forms.DateField(widget=DateInput(
             max_date=max_date,
             min_date=min_date,
-            format=format,
+            date_format=date_format,
             change_year=change_year,
             change_month=change_month
         )),
