@@ -1,7 +1,8 @@
 # coding=utf-8
 from django_helpers.helpers.templatetags import TemplateNode, parse_args
 from django_helpers.helpers.views import render_to_string
-from django_helpers.templatetags.static_manger import register, require_jquery
+from django_helpers.apps.static_manager import require_jquery
+from django_helpers.templatetags.jsmin import register
 
 
 __author__ = 'ajumell'
